@@ -24,7 +24,7 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
+#include <stdlib.h>
 #include <gio/gio.h>
 #include <glib/gstdio.h>
 #include <archive.h>
@@ -126,7 +126,6 @@ main (int argc, char *argv[])
 	DVContents * context;
 	gchar **remaining_args;
 	GOptionContext *option_context;
-	GnomeProgram * dv;
 	gboolean check_vfs;
 	GtkDialog * dialog;
 	GtkWindow * window1;
@@ -151,10 +150,8 @@ main (int argc, char *argv[])
 	option_context = g_option_context_new ("");
 	g_option_context_add_main_entries (option_context,
 		option_entries, GETTEXT_PACKAGE);
-	dv = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
-		argc, argv, GNOME_PARAM_HUMAN_READABLE_NAME, _(GETTEXT_PACKAGE),
-		GNOME_PARAM_APP_DATADIR, PACKAGE_DATA_DIR,
-		GNOME_PARAM_GOPTION_CONTEXT, option_context, GNOME_PARAM_NONE);
+	g_option_context_parse (option_context, &argc, &argv, NULL);
+	gtk_init (&argc, &argv);
 	add_pixmap_directory (PACKAGE_PIXMAP_DIR);
 	subwindows = NULL;
 	if (!preview_init ())
